namespace elm { namespace app { namespace server { 
inline ::efl::eolian::return_traits<short>::type View::progress_get() const
{
   short __return_value =  ::elm_app_server_view_progress_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<short>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::progress_set( ::efl::eolian::in_traits<short>::type progress) const
{
    ::elm_app_server_view_progress_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<short,  ::efl::eolian::in_traits<short>::type>(progress));
}
inline ::efl::eolian::return_traits<int>::type View::new_events_get() const
{
   int __return_value =  ::elm_app_server_view_new_events_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::new_events_set( ::efl::eolian::in_traits<int>::type events) const
{
    ::elm_app_server_view_new_events_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(events));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type View::icon_get() const
{
   const char * __return_value =  ::elm_app_server_view_icon_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::icon_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type icon) const
{
    ::elm_app_server_view_icon_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(icon));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type View::title_get() const
{
   const char * __return_value =  ::elm_app_server_view_title_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::title_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type title) const
{
    ::elm_app_server_view_title_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(title));
}
inline ::efl::eolian::return_traits<void>::type View::window_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type win) const
{
    ::elm_app_server_view_window_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(win));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type View::id_get() const
{
   const char * __return_value =  ::elm_app_server_view_id_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::id_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type ret) const
{
    ::elm_app_server_view_id_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(ret));
}
inline ::efl::eolian::return_traits<Elm_App_View_State>::type View::state_get() const
{
   Elm_App_View_State __return_value =  ::elm_app_server_view_state_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_App_View_State>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type View::path_get() const
{
   const char * __return_value =  ::elm_app_server_view_path_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::pause() const
{
    ::elm_app_server_view_pause(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type View::resume() const
{
    ::elm_app_server_view_resume(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type View::shallow() const
{
    ::elm_app_server_view_shallow(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type View::close() const
{
    ::elm_app_server_view_close(this->_eo_ptr());
}
} } } 
namespace eo_cxx {
namespace elm { namespace app { namespace server { 
inline ::efl::eolian::return_traits<short>::type View::progress_get() const
{
   short __return_value =  ::elm_app_server_view_progress_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<short>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::progress_set( ::efl::eolian::in_traits<short>::type progress) const
{
    ::elm_app_server_view_progress_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<short,  ::efl::eolian::in_traits<short>::type>(progress));
}
inline ::efl::eolian::return_traits<int>::type View::new_events_get() const
{
   int __return_value =  ::elm_app_server_view_new_events_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<int>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::new_events_set( ::efl::eolian::in_traits<int>::type events) const
{
    ::elm_app_server_view_new_events_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<int,  ::efl::eolian::in_traits<int>::type>(events));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type View::icon_get() const
{
   const char * __return_value =  ::elm_app_server_view_icon_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::icon_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type icon) const
{
    ::elm_app_server_view_icon_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(icon));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type View::title_get() const
{
   const char * __return_value =  ::elm_app_server_view_title_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::title_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type title) const
{
    ::elm_app_server_view_title_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(title));
}
inline ::efl::eolian::return_traits<void>::type View::window_set( ::efl::eolian::in_traits< ::efl::canvas::Object>::type win) const
{
    ::elm_app_server_view_window_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c< ::Efl_Canvas_Object*,  ::efl::eolian::in_traits< ::efl::canvas::Object>::type>(win));
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type View::id_get() const
{
   const char * __return_value =  ::elm_app_server_view_id_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::id_set( ::efl::eolian::in_traits< ::efl::eina::string_view>::type ret) const
{
    ::elm_app_server_view_id_set(this->_eo_ptr()
      ,  ::efl::eolian::convert_to_c<const char *,  ::efl::eolian::in_traits< ::efl::eina::string_view>::type>(ret));
}
inline ::efl::eolian::return_traits<Elm_App_View_State>::type View::state_get() const
{
   Elm_App_View_State __return_value =  ::elm_app_server_view_state_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits<Elm_App_View_State>::type>(__return_value);
}
inline ::efl::eolian::return_traits< ::efl::eina::string_view>::type View::path_get() const
{
   const char * __return_value =  ::elm_app_server_view_path_get(this->_eo_ptr());
   return ::efl::eolian::convert_to_return< ::efl::eolian::return_traits< ::efl::eina::string_view>::type>(__return_value);
}
inline ::efl::eolian::return_traits<void>::type View::pause() const
{
    ::elm_app_server_view_pause(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type View::resume() const
{
    ::elm_app_server_view_resume(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type View::shallow() const
{
    ::elm_app_server_view_shallow(this->_eo_ptr());
}
inline ::efl::eolian::return_traits<void>::type View::close() const
{
    ::elm_app_server_view_close(this->_eo_ptr());
}
inline elm::app::server::View::operator ::elm::app::server::View() const { return *static_cast< ::elm::app::server::View const*>(static_cast<void const*>(this)); }
inline elm::app::server::View::operator ::elm::app::server::View&() { return *static_cast< ::elm::app::server::View*>(static_cast<void*>(this)); }
inline elm::app::server::View::operator ::elm::app::server::View const&() const { return *static_cast< ::elm::app::server::View const*>(static_cast<void const*>(this)); }
} } } }

